SmartDialogStyle enum

Dialog visual style.

Inheritance
Available extensions

Values

standard → const SmartDialogStyle

Standard dialog with title + message + buttons

withHeader → const SmartDialogStyle

Dialog with large icon/image at top (floating header style)

bottomSheet → const SmartDialogStyle

Bottom sheet style dialog

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SmartDialogStyle>
A constant List of the values in this enum, in order of their declaration.